# ``arxiv.users`` Library

This package provides core functionality for working with users and sessions
in arXiv-NG services. Housing these components in a library (separate from
service implementations) ensures that users and sessions are represented
and manipulated consistently. In addition to NG components, this package
also provides integrations with the legacy user and session data in the
classic database.
